package net.knarcraft.paidsigns.command;

import net.knarcraft.knarlib.util.TabCompletionHelper;
import net.knarcraft.paidsigns.utility.PaidSignsTabCompleteHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * The tab completer for the add paid sign command
 */
public class AddTabCompleter extends TokenizedTabCompleter {

    private static List<String> names;
    private static List<String> costs;
    private static List<String> options;
    private static List<String> booleans;

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias,
                                      @NotNull String[] args) {
        super.onTabComplete(sender, command, alias, args);
        if (names == null) {
            initializeValues();
        }

        if (argumentSize == 1) {
            return TabCompletionHelper.filterMatchingStartsWith(names, arguments.get(0));
        } else if (argumentSize == 2) {
            return TabCompletionHelper.filterMatchingStartsWith(costs, arguments.get(1));
        } else if (argumentSize == 3) {
            return PaidSignsTabCompleteHelper.tabCompletePermission(arguments.get(arguments.size() - 1));
        } else if (argumentSize == 4) {
            return TabCompletionHelper.filterMatchingStartsWith(options, arguments.get(3));
        } else if (argumentSize == 5) {
            return TabCompletionHelper.filterMatchingStartsWith(options, arguments.get(4));
        } else if (argumentSize == 6) {
            return TabCompletionHelper.filterMatchingStartsWith(booleans, arguments.get(5));
        }
        return new ArrayList<>();
    }

    /**
     * Initializes the values available for tab completion
     */
    private static void initializeValues() {
        names = PaidSignsTabCompleteHelper.getExamplePaidSignNames();
        costs = PaidSignsTabCompleteHelper.getCosts();
        options = PaidSignsTabCompleteHelper.getOptionStates();
        booleans = PaidSignsTabCompleteHelper.getBooleans();
    }

}
