package net.knarcraft.paidsigns.command;

import net.knarcraft.knarlib.util.TabCompletionHelper;
import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.container.PaidSign;
import net.knarcraft.paidsigns.utility.PaidSignsTabCompleteHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * The tab completer for the remove paid sign condition command
 */
public class RemoveConditionTabCompleter extends TokenizedTabCompleter {

    private List<String> lineIndices;

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias,
                                      @NotNull String[] args) {
        super.onTabComplete(sender, command, alias, args);
        if (lineIndices == null) {
            initializeValues();
        }

        if (argumentSize == 1) {
            return TabCompletionHelper.filterMatchingStartsWith(PaidSignsTabCompleteHelper.getPaidSignNames(), arguments.get(0));
        } else if (argumentSize == 2) {
            PaidSign sign = PaidSigns.getInstance().getSignManager().getPaidSign(arguments.get(0));
            if (sign != null) {
                List<String> availableConditions = new ArrayList<>();
                for (Short signLine : sign.getConditions().keySet()) {
                    availableConditions.add(String.valueOf(signLine + 1));
                }
                return TabCompletionHelper.filterMatchingStartsWith(availableConditions, arguments.get(1));
            }
        }
        return new ArrayList<>();
    }

    /**
     * Initializes the values available for tab completion
     */
    private void initializeValues() {
        lineIndices = PaidSignsTabCompleteHelper.getSignLines();
    }

}
