package net.knarcraft.paidsigns.command;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.formatting.PaidSignsTranslatableMessage;
import net.knarcraft.paidsigns.utility.Tokenizer;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;

/**
 * A command executor with tokenized arguments
 */
public class TokenizedCommand implements CommandExecutor {

    protected List<String> arguments;
    protected int argumentSize;

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        arguments = Tokenizer.tokenize(String.join(" ", args));
        argumentSize = arguments.size();
        return true;
    }

    /**
     * Tests whether the given regular expression is valid
     *
     * @param sender            <p>The command sender to notify if the regular expression is invalid</p>
     * @param regularExpression <p>The regular expression to test</p>
     * @return <p>True if the regular expression is invalid</p>
     */
    protected boolean isRegExInvalid(CommandSender sender, String regularExpression) {
        try {
            Pattern.compile(regularExpression);
            return false;
        } catch (PatternSyntaxException exception) {
            PaidSigns.getStringFormatter().displayErrorMessage(sender,
                    PaidSignsTranslatableMessage.ERROR_INVALID_REGULAR_EXPRESSION);
            return true;
        }
    }

}
