package net.knarcraft.paidsigns.container;

import org.bukkit.block.sign.Side;

import java.util.UUID;

/**
 * A representation of a sign placed by a player that matched a paid sign
 *
 * @param playerId  <p>The unique id of the player that created the sign</p>
 * @param frontCost <p>The cost the player paid for creating the front of the sign</p>
 * @param backCost  <p>The cost the player paid for creating the back of the sign</p>
 */
public record TrackedSign(UUID playerId, double frontCost, double backCost) {

    /**
     * Gets an instance of a tracked sign
     *
     * @param playerId <p>The unique id of the player that created the sign</p>
     * @param side     <p>The side the player paid for</p>
     * @param cost     <p>The cost the player paid for creating the side of the sign</p>
     * @return <p>A tracked sign instance</p>
     */
    public static TrackedSign getInstance(UUID playerId, Side side, double cost) {
        if (side == Side.FRONT) {
            return new TrackedSign(playerId, cost, 0);
        } else {
            return new TrackedSign(playerId, 0, cost);
        }
    }

    /**
     * Gets the cost paid for the given side
     *
     * @param side <p>The side to check the cost for</p>
     * @return <p>The cost the player paid</p>
     */
    public double getCost(Side side) {
        return switch (side) {
            case FRONT -> frontCost;
            case BACK -> backCost;
        };
    }

}
