package net.knarcraft.paidsigns.formatting;

import net.knarcraft.knarlib.formatting.TranslatableMessage;

/**
 * An enum representing all translatable messages
 */
public enum PaidSignsTranslatableMessage implements TranslatableMessage {

    /**
     * The message to display when a paid sign is successfully added
     */
    SUCCESS_ADDED_PAID_SIGN,

    /**
     * The message to display when a paid sign condition is successfully added
     */
    SUCCESS_ADDED_PAID_SIGN_CONDITION,

    /**
     * The message to display when a paid sign is successfully updated
     */
    SUCCESS_UPDATED_PAID_SIGN,

    /**
     * The message to display when a paid sign condition is successfully updated
     */
    SUCCESS_UPDATED_PAID_SIGN_CONDITION,

    /**
     * The message to display when a paid sign has been successfully removed
     */
    SUCCESS_REMOVED_PAID_SIGN,

    /**
     * The message to display when a paid sign condition has been successfully removed
     */
    SUCCESS_REMOVED_CONDITION,

    /**
     * The message to display after the plugin has been reloaded
     */
    SUCCESS_RELOADED,

    /**
     * The message to display when a player has been charged for creating a paid sign
     */
    SUCCESS_PAID_FOR_SIGN,

    /**
     * The message to display when a player has been refunded for breaking a sign
     */
    SUCCESS_REFUNDED,

    /**
     * The info text used to display all paid signs
     */
    PAID_SIGNS_INFO,

    /**
     * The format used for displaying a paid sign's name
     */
    PAID_SIGNS_INFO_FORMAT,

    /**
     * The prompt displayed when the paid sign list has more items
     */
    PAID_SIGNS_NEXT_PROMPT,

    /**
     * The info text used to display information about a paid sign
     */
    PAID_SIGN_INFO,

    /**
     * The info text used to display information about a paid sign condition
     */
    PAID_SIGN_CONDITION_INFO,

    /**
     * The format used for displaying one of a paid sign's conditions
     */
    PAID_SIGN_INFO_CONDITION_FORMAT,

    /**
     * The message to display for a true boolean value
     */
    BOOLEAN_TRUE,

    /**
     * The message to display for a false boolean value
     */
    BOOLEAN_FALSE,

    /**
     * The error to display when a command argument contains an invalid number
     */
    ERROR_INVALID_NUMBER,

    /**
     * The error to display if a paid sign name duplicate is encountered
     */
    ERROR_NAME_DUPLICATE,

    /**
     * The error to display if a severe exception occurs
     */
    ERROR_EXCEPTION_OCCURRED,

    /**
     * The error to display if some input is invalid
     */
    ERROR_INVALID_INPUT,

    /**
     * The error to display if a specified paid sign is not found
     */
    ERROR_PAID_SIGN_NOT_FOUND,

    /**
     * The error to display if a paid sign condition is specified, but does not exist
     */
    ERROR_NO_SUCH_CONDITION,

    /**
     * The error to display if a player cannot pay for a sign matching a paid sign
     */
    ERROR_CANNOT_AFFORD,

    /**
     * The error to display if an invalid regular expression is provided
     */
    ERROR_INVALID_REGULAR_EXPRESSION,

    /**
     * The error to display if an invalid property is given to the edit command
     */
    ERROR_PROPERTY_NOT_RECOGNIZED,
    ;

    @Override
    public TranslatableMessage[] getAllMessages() {
        return PaidSignsTranslatableMessage.values();
    }
}
