package net.knarcraft.paidsigns.listener;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.manager.TrackedSignManager;
import net.knarcraft.paidsigns.utility.SignHelper;
import org.bukkit.block.Block;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.bukkit.event.Listener;
import org.bukkit.event.block.BlockBreakEvent;
import org.bukkit.event.block.BlockExplodeEvent;
import org.bukkit.event.block.BlockPistonExtendEvent;
import org.bukkit.event.block.BlockPistonRetractEvent;
import org.bukkit.event.entity.EntityChangeBlockEvent;
import org.bukkit.event.entity.EntityExplodeEvent;

import java.io.IOException;
import java.util.List;

/**
 * A listener that listens for any tracked signs being broken
 */
public class SignBreakListener implements Listener {

    @EventHandler(priority = EventPriority.MONITOR)
    public void onBlockBreak(BlockBreakEvent event) {
        if (event.isCancelled()) {
            return;
        }
        removeTrackedSign(event.getBlock(), true);
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onExplosion(BlockExplodeEvent event) {
        if (event.isCancelled()) {
            return;
        }
        removeTrackedSigns(event.blockList());
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onEntityExplosion(EntityExplodeEvent event) {
        if (event.isCancelled()) {
            return;
        }
        removeTrackedSigns(event.blockList());
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onPistonPush(BlockPistonExtendEvent event) {
        if (event.isCancelled()) {
            return;
        }
        removeTrackedSigns(event.getBlocks());
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onPistonPull(BlockPistonRetractEvent event) {
        if (event.isCancelled()) {
            return;
        }
        removeTrackedSigns(event.getBlocks());
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onEntityBlockChange(EntityChangeBlockEvent event) {
        if (event.isCancelled()) {
            return;
        }
        if (event.getEntity() instanceof Player) {
            return;
        }
        removeTrackedSign(event.getBlock(), PaidSigns.getInstance().refundAlways());
    }

    /**
     * Removes all tracked signs from the given blocks
     *
     * @param blocks <p>The blocks to search for tracked signs</p>
     */
    private void removeTrackedSigns(List<Block> blocks) {
        for (Block block : blocks) {
            removeTrackedSign(block, PaidSigns.getInstance().refundAlways());
        }
    }

    /**
     * Tries to remove any tracked sign at the given block
     *
     * @param block  <p>The block that might be a sign</p>
     * @param refund <p>Whether to perform a refund after un-tracking the sign</p>
     */
    private void removeTrackedSign(Block block, boolean refund) {
        if (SignHelper.isSign(block)) {
            try {
                TrackedSignManager.removeTrackedSign(block.getLocation(), refund, false);
            } catch (IOException ignored) {
            }
        }
    }

}
